@@ -20,7 +20,7 @@
 */
 
 /*
- *  $Id: network.cpp,v 1.21 2005/06/20 20:34:06 cepek Exp $
+ *  $Id: network.cpp,v 1.23 2005/12/28 17:27:05 cepek Exp $
  */
 
 #include <fstream>
@@ -33,8 +33,9 @@
 #include <gamalib/local/network.h>
 #include <gamalib/local/linearization.h>
 #include <gamalib/itstream.h>
-#include <gnu_gama/statan.h>
 #include <gamalib/skipcomm.h>
+#include <gnu_gama/statan.h>
+#include <gnu_gama/sparse/smatrix_graph.h>
 #include <gnu_gama/version.h>
 
 using namespace std;
@@ -232,6 +233,12 @@ void LocalNetwork::project_equations()
     Asp =  tmp->replicate(tmp->nonzeroes(), pocmer_, pocet_neznamych_ );
     delete tmp;
 
+    {
+      GNU_gama::SparseMatrixGraph<> graph(Asp);
+
+      design_matrix_graph_is_connected = graph.connected();
+    }
+
     Double* a = Asp->begin(1);
     Index*  i = Asp->ibegin(1);
     for (int n, row=1; row<=pocmer_; row++)
@@ -525,8 +532,10 @@ Double LocalNetwork::test_abs_term(Index indm)
 {
   const Observation* m = RSM[indm-1];
 
-  if (dynamic_cast<const Coordinates*>(m->ptr_cluster())) return 0;
-  if (dynamic_cast<const Vectors*>(m->ptr_cluster())) return 0;
+  // 2005-12-28 added test for coordinates and vectors
+  //
+  // if (dynamic_cast<const Coordinates*>(m->ptr_cluster())) return 0;
+  // if (dynamic_cast<const Vectors*>(m->ptr_cluster())) return 0;
 
   const LocalPoint& stan = PD[m->from()];
   const LocalPoint& cil  = PD[m->to()];   // ignoring second angle target here
@@ -588,6 +597,51 @@ Double LocalNetwork::test_abs_term(Index indm)
         else
           return 0;   
       }
+    else if (typeid(*m) == typeid(Xdiff))
+      {
+        const Double dx = cil.x() - stan.x();
+        if (fabs(dx - m->value())*1000 > tol_abs_)
+          return b(indm);
+        else
+          return 0;           
+      }
+    else if (typeid(*m) == typeid(Ydiff))
+      {
+        const Double dy = cil.y() - stan.y();
+        if (fabs(dy - m->value())*1000 > tol_abs_)
+          return b(indm);
+        else
+          return 0;           
+      }
+    else if (typeid(*m) == typeid(Zdiff))
+      {
+        const Double dz = cil.z() - stan.z();
+        if (fabs(dz - m->value())*1000 > tol_abs_)
+          return b(indm);
+        else
+          return 0;           
+      }
+    else if (typeid(*m) == typeid(X))
+      {
+        if (fabs(stan.x() - m->value())*1000 > tol_abs_)
+          return b(indm);
+        else
+          return 0;           
+      }
+    else if (typeid(*m) == typeid(Y))
+      {
+        if (fabs(stan.y() - m->value())*1000 > tol_abs_)
+          return b(indm);
+        else
+          return 0;           
+      }
+    else if (typeid(*m) == typeid(Z))
+      {
+        if (fabs(stan.z() - m->value())*1000 > tol_abs_)
+          return b(indm);
+        else
+          return 0;           
+      }
   } 
 
   throw GaMaLib::Exception("LocalNetwork::test_abs_term() - unknown observation");
