@@ -16,11 +16,11 @@
 
     You should have received a copy of the GNU General Public License
     along with this library; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 */
 
 /*
- *  $Id: angle.cpp,v 1.3 2003/11/06 17:58:58 cepek Exp $
+ *  $Id: angle.cpp,v 1.5 2005/05/07 18:06:20 cepek Exp $
  */
 
 #include <iostream>
@@ -28,22 +28,30 @@
 #include <gamalib/observation.h>
 #include <gamalib/local/pobs/bearing.h>
 #include <gamalib/local/pobs/format.h>
+#include <gnu_gama/gon2deg.h>
 
 using namespace GaMaLib;
 using namespace std;
 
-
 void Angle::write(std::ostream& out, bool print_at) const
 {
-  using namespace std;
   out << "<angle";
   if (print_at)
     out << " from=\"" << from() << '"';
-  out << " bs=\"" << bs()  << '"'
-      << " fs=\"" << fs() << '"'
-      << " val=\""   << setprecision(Format::gon_p()  ) << value()*R2G << '"';
+
+  out << " bs=\"" << bs()  << '"' << " fs=\"" << fs() << '"' << " val=\"";
+  if (Observation::gons)
+    out << setprecision(Format::gon_p()) << value()*R2G;
+  else
+    out << GNU_gama::gon2deg(value()*R2G, 2, Format::gon_p());
+  out << '"';
+
   if (check_std_dev())
-    out << " stdev=\"" << setprecision(Format::stdev_p()) << stdDev()    << '"';
+    {
+      double stddev = Observation::gons ? stdDev() : stdDev()*0.324;
+      out << " stdev=\"" << setprecision(Format::stdev_p()) << stddev << '"';
+    }
+
   out << " />";
 }
 
