@@ -18,11 +18,11 @@
 
     You should have received a copy of the GNU General Public License
     along with this library; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 */
 
 /*
- *  $Id: pointid.h,v 1.3 2004/04/04 11:19:29 cepek Exp $
+ *  $Id: pointid.h,v 1.5 2005/05/07 18:06:19 cepek Exp $
  */
 
 // PointID - point identification 
@@ -98,7 +98,7 @@ namespace GaMaLib
         }
       
       #ifndef _MSC_VER
-      std::   /* one of ms improvements of C++ standard */
+      std::   
       #endif
            size_t length() const
         {
