@@ -20,7 +20,7 @@
 */
 
 /*
- *  $Id: g3_model.h,v 1.37 2005/09/28 14:35:59 cepek Exp $
+ *  $Id: g3_model.h,v 1.49 2005/12/28 17:27:05 cepek Exp $
  */
 
 #ifndef GNU_gama__g3_model_h_gnugamag3modelh___gnu_gama_g3model
@@ -37,27 +37,11 @@
 #include <gnu_gama/sparse/sbdiagonal.h>
 #include <gnu_gama/adj/adj.h>
 #include <gnu_gama/e3.h>
+#include <list>
 
 namespace GNU_gama {  namespace g3 {
 
-    class Model : 
-    public GNU_gama::Model<g3::Observation>,
-    public Revision     <Distance>,
-    public Linearization<Distance>,
-    public Revision     <Vector>,
-    public Linearization<Vector>,
-    public Revision     <XYZ>,
-    public Linearization<XYZ>,
-    public Revision     <ZenithAngle>,
-    public Linearization<ZenithAngle>,
-    public Revision     <Azimuth>,
-    public Linearization<Azimuth>,
-    public Revision     <HeightDiff>,
-    public Linearization<HeightDiff>,
-    public Revision     <Height>,
-    public Linearization<Height>,
-    public Revision     <Angle>,
-    public Linearization<Angle>
+  class Model : public GNU_gama::Model<g3::Observation>
   {
   public:
     
@@ -93,22 +77,32 @@ namespace GNU_gama {  namespace g3 {
     void update_linearization();
     void update_adjustment();
         
-    bool revision_visit     (Distance*   );
-    void linearization_visit(Distance*   );
-    bool revision_visit     (Vector*     );
-    void linearization_visit(Vector*     );
-    bool revision_visit     (XYZ*        );
-    void linearization_visit(XYZ*        );
-    bool revision_visit     (ZenithAngle*);
-    void linearization_visit(ZenithAngle*);
-    bool revision_visit     (Azimuth*    );
-    void linearization_visit(Azimuth*    );
-    bool revision_visit     (HeightDiff* );
-    void linearization_visit(HeightDiff* );
-    bool revision_visit     (Height*     );
-    void linearization_visit(Height*     );
-    bool revision_visit     (Angle*      );
-    void linearization_visit(Angle*      );
+    bool revision(Angle*      );
+    bool revision(Azimuth*    );
+    bool revision(Distance*   );
+    bool revision(Height*     );
+    bool revision(HeightDiff* );
+    bool revision(Vector*     );
+    bool revision(XYZ*        );
+    bool revision(ZenithAngle*);
+
+    void linearization(Angle*      );
+    void linearization(Azimuth*    );
+    void linearization(Distance*   );
+    void linearization(Height*     );
+    void linearization(HeightDiff* );
+    void linearization(Vector*     );
+    void linearization(XYZ*        );
+    void linearization(ZenithAngle*);
+
+    void write_xml_adjusted(std::ostream&, const Angle*,      Index);
+    void write_xml_adjusted(std::ostream&, const Azimuth*,    Index);
+    void write_xml_adjusted(std::ostream&, const Distance*,   Index);
+    void write_xml_adjusted(std::ostream&, const Vector*,     Index);
+    void write_xml_adjusted(std::ostream&, const Height*,     Index);
+    void write_xml_adjusted(std::ostream&, const HeightDiff*, Index);
+    void write_xml_adjusted(std::ostream&, const XYZ*,        Index);
+    void write_xml_adjusted(std::ostream&, const ZenithAngle*,Index);
 
     void set_algorithm(Adj::algorithm a) { adj->set_algorithm(a); }
 
@@ -118,7 +112,11 @@ namespace GNU_gama {  namespace g3 {
     double get_conf_level() const   { return confidence_level; } 
 
     double standard_deviation() const { return std_deviation; }
-    double q_xx(Index i, Index j) { return adj->q_xx(i,j); }
+    double standard_variance () const { return std_variance; }
+    double cov_xx(Index i, Index j) { return std_variance*adj->q_xx(i,j); }
+    double cov_bb(Index i, Index j) { return std_variance*adj->q_bb(i,j); }
+
+    bool   graph_is_connected() const  { return dm_graph_is_connected; }
 
     void write_xml_adjustment_input_data(std::ostream&);
     void write_xml_adjustment_results   (std::ostream&);
@@ -133,6 +131,20 @@ namespace GNU_gama {  namespace g3 {
     GNU_gama::E_3 vertical  (const Point* p) const;
     GNU_gama::E_3 instrument(const Point* p, double dh) const;
 
+    
+    struct Rejected 
+    {
+      enum rejection { rhs };
+
+      rejection     criterion;
+      Observation*  observation;
+      double        data[3];
+    };
+
+    typedef std::list<Rejected>  RejectedObs;
+    RejectedObs     rejected_obs;
+
+
   private:   /*-----------------------------------------------------------*/
       
     Model(const Model&);
@@ -161,6 +173,7 @@ namespace GNU_gama {  namespace g3 {
     BlockDiagonal<>*  B;
     GNU_gama::AdjInputData*  adj_input_data;
 
+
     // adjustment
     Adj*              adj;
 
@@ -168,13 +181,31 @@ namespace GNU_gama {  namespace g3 {
     enum { apriori, aposteriori } actual_sd;
     double aposteriori_sd;
     double std_deviation;
-    
+    double std_variance;
+
+    bool   dm_graph_is_connected;   // design matrix graph
+
 
     // constants
     double apriori_sd;
     double confidence_level;
 
     bool   gons_;
+
+
+    void write_xml_rejected_observations          (std::ostream&);  
+    void write_xml_adjustment_results_statistics  (std::ostream&);
+    void write_xml_adjustment_results_points      (std::ostream&);
+    void write_xml_adjustment_results_observations(std::ostream&);
+
+    bool accepted;
+
+    void write_xml_adjusted_stdev  (const char*, 
+                                    std::ostream&, const Observation*,
+                                    Index, Index);
+
+    void write_xml_adjusted_cov_xyz(std::ostream&, const Observation*,
+                                    Index);
   };
   
 }}
