@@ -20,7 +20,7 @@
 */
 
 /*
- *  $Id: g3_point.cpp,v 1.39 2005/09/22 18:20:39 cepek Exp $
+ *  $Id: g3_point.cpp,v 1.44 2005/10/23 15:08:35 cepek Exp $
  */
 
 #include <gnu_gama/g3/g3_point.h>
@@ -311,26 +311,24 @@ double Point::diff_U() const
 
 void Point::set_cov_neu()
 {
-  cnn = cne = cnu = cee = ceu = cuu = 123;
+  cnn = cne = cnu = cee = ceu = cuu = 0.0;
   Index n = N.index();
   Index e = E.index();
   Index u = U.index();
-  double s = common->standard_deviation();
-  double q = s*s;
   if (n)
     {
-      cnn = q * common->q_xx(n,n);
-      if (e) cne = q * common->q_xx(n,e);
-      if (u) cnu = q * common->q_xx(n,u);
+      cnn = common->cov_xx(n,n);
+      if (e) cne = common->cov_xx(n,e);
+      if (u) cnu = common->cov_xx(n,u);
     }
   if (e)
     {
-      cee = q * common->q_xx(e,e);
-      if (u) ceu = q * common->q_xx(e,u);
+      cee = common->cov_xx(e,e);
+      if (u) ceu = common->cov_xx(e,u);
     }
   if (u)
     {
-      cuu = q * common->q_xx(u,u);
+      cuu = common->cov_xx(u,u);
     }
 }
 
@@ -358,6 +356,29 @@ void Point::set_cov_xyz()
   czz = t31*r31 + t32*r32 + t33*r33;
 }
 
+bool Point::test_model_height() const
+{
+  if (1)
+    {
+      if (!has_position()) return false;
+      if (!has_geoid()   ) return false;
+    }
+  else
+    {
+      if (!has_height()) return false;
+    }
+  
+  return true;
+}
+
+double Point::model_height() const
+{
+  if (1)
+    return H() - geoid();
+  else
+    return height();
+}
+
 void Point::write_xml(std::ostream& ostr)
 {
   const double n = N();
@@ -428,18 +449,17 @@ void Point::write_xml(std::ostream& ostr)
 
       ostr.setf(std::ios_base::scientific, std::ios_base::floatfield);
       ostr.precision(7);
-      ostr << "\n        <cov-mat> <dim>3</dim> <band>2</band>\n";
+      ostr << "\n";
       ostr << "        ";
-      ostr << "<flt> " << cnn << " </flt> ";
-      ostr << "<flt> " << setw(14) << cne << " </flt> ";
+      ostr << "<cnn> " << cnn << " </cnn> ";
+      ostr << "<cne> " << setw(14) << cne << " </cne> ";
       ostr << "\n                                   ";
-      ostr << "<flt> " << setw(14) << cnu << " </flt>\n";
+      ostr << "<cnu> " << setw(14) << cnu << " </cnu>\n";
       ostr << "        "; 
-      ostr << "<flt> " << cee << " </flt> ";
-      ostr << "<flt> " << setw(14) << ceu << " </flt>\n";
+      ostr << "<cee> " << cee << " </cee> ";
+      ostr << "<ceu> " << setw(14) << ceu << " </ceu>\n";
       ostr << "        "; 
-      ostr << "<flt> " << cuu << " </ftl>\n";
-      ostr << "        </cov-mat>\n";
+      ostr << "<cuu> " << cuu << " </cuu>\n";
     }
 
   if (has_position())
@@ -493,18 +513,17 @@ void Point::write_xml(std::ostream& ostr)
 
       ostr.setf(std::ios_base::scientific, std::ios_base::floatfield);
       ostr.precision(7);
-      ostr << "\n        <cov-mat> <dim>3</dim> <band>2</band>\n";
+      ostr << "\n";
       ostr << "        ";
-      ostr << "<flt> " << cxx << " </flt> ";
-      ostr << "<flt> " << setw(14) << cxy << " </flt> ";
+      ostr << "<cxx> " << cxx << " </cxx> ";
+      ostr << "<cxy> " << setw(14) << cxy << " </cxy> ";
       ostr << "\n                                   ";
-      ostr << "<flt> " << setw(14) << cxz << " </flt>\n";
+      ostr << "<cxz> " << setw(14) << cxz << " </cxz>\n";
       ostr << "        ";
-      ostr << "<flt> " << cyy << " </flt> ";
-      ostr << "<flt> " << setw(14) << cyz << " </flt>\n";
+      ostr << "<cyy> " << cyy << " </cyy> ";
+      ostr << "<cyz> " << setw(14) << cyz << " </cyz>\n";
       ostr << "        ";
-      ostr << "<flt> " << czz << " </ftl>\n";
-      ostr << "        </cov-mat>\n";
+      ostr << "<czz> " << czz << " </czz>\n";
     }
 
   if (has_position())
