@@ -20,7 +20,7 @@
 */
 
 /*
- *  $Id: g3_point.h,v 1.32 2005/09/23 17:17:29 cepek Exp $
+ *  $Id: g3_point.h,v 1.34 2005/10/13 18:57:50 cepek Exp $
  */
 
 #include <string>
@@ -46,7 +46,7 @@ namespace GNU_gama {  namespace g3 {
     Linear    N;
     Linear    E;
     Linear    U;
-    Parameter height;
+    Linear    height;
     Parameter geoid;
     Parameter dB;
     Parameter dL;
@@ -96,6 +96,9 @@ namespace GNU_gama {  namespace g3 {
     bool has_height()   const { return has_height_; }
     bool has_geoid()    const { return has_geoid_;  }
 
+    bool   test_model_height() const;
+    double model_height()      const;
+
     double X_dh(double dh) const { return X() + r13*dh; }
     double Y_dh(double dh) const { return Y() + r23*dh; }
     double Z_dh(double dh) const { return Z() + r33*dh; }
