@@ -1,6 +1,6 @@
 /*  
     GNU Gama -- adjustment of geodetic networks
-    Copyright (C) 2003  Ales Cepek <cepek@fsv.cvut.cz>
+    Copyright (C) 2003  Ales Cepek <cepek@gnu.org>
 
     This file is part of the GNU Gama C++ library.
     
@@ -20,7 +20,7 @@
 */
 
 /*
- *  $Id: outstream.cpp,v 1.4 2005/05/07 18:06:20 cepek Exp $
+ *  $Id: outstream.cpp,v 1.6 2005/08/23 19:50:29 cepek Exp $
  */
 
 
@@ -175,6 +175,9 @@ const char* OutStream::recode(const char* s)
     case cp_1250: 
       utf8_cp1250((char*)text.c_str());
       break;
+    case cp_1251: 
+      utf8_cp1251((char*)text.c_str());
+      break;
     default:
       break;
     }
@@ -182,4 +185,3 @@ const char* OutStream::recode(const char* s)
   return text.c_str();
 }
 
-
