@@ -1,6 +1,6 @@
 /*  
     GNU Gama --- Geodesy and Mapping C++ library 
-    Copyright (C) 2004  Ales Cepek <cepek@fsv.cvut.cz>
+    Copyright (C) 2004  Ales Cepek <cepek@gnu.org>
 
     This file is part of the GNU Gama C++ library.
     
@@ -20,7 +20,7 @@
 */
 
 /*
- *  $Id: radian.h,v 1.2 2005/05/07 18:06:20 cepek Exp $
+ *  $Id: radian.h,v 1.4 2005/08/30 18:33:29 cepek Exp $
  */
 
 
@@ -50,6 +50,22 @@ namespace GNU_gama {
 #define CC_TO_RAD     M_PI/200.0e4
 #endif
 
+#ifndef RAD_TO_DEG
+#define RAD_TO_DEG    180.0/M_PI
+#endif
+
+#ifndef DEG_TO_RAD
+#define DEG_TO_RAD    M_PI/180.0
+#endif
+
+#ifndef RAD_TO_SS
+#define RAD_TO_SS     648000.0/M_PI
+#endif
+
+#ifndef SS_TO_RAD
+#define SS_TO_RAD     M_PI/648000.0
+#endif
+
 }
 
 
