@@ -1,8 +1,8 @@
 /*  
     Geodesy and Mapping C++ Library (GNU GaMa / GaMaLib)
-    Copyright (C) 1999  Ales Cepek <cepek@fsv.cvut.cz>
+    Copyright (C) 1999  Ales Cepek <cepek@gnu.org>
 
-    This file is part of the GNU GaMa / GaMaLib C++ Library.
+    This file is part of the GNU Gama C++ library.
     
     This library is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -20,7 +20,7 @@
 */
 
 /*
- *  $Id: statan.cpp,v 1.4 2005/05/07 18:06:20 cepek Exp $
+ *  $Id: statan.cpp,v 1.6 2005/08/06 20:27:29 cepek Exp $
  */
 
 #include <gnu_gama/statan.h>
