@@ -20,7 +20,7 @@
 */
 
 /*
- *  $Id: version.cpp,v 1.83 2005/09/30 11:52:02 cepek Exp $
+ *  $Id: version.cpp,v 1.92 2005/12/28 20:59:09 cepek Exp $
  */
 
 
@@ -28,7 +28,7 @@
 
 namespace GNU_gama {
 
-const char* GNU_gama_version  = "1.7.14";
+const char* GNU_gama_version  = "1.8.00";
 
 const char* GNU_gama_compiler =
               #if   defined (__GNUC__)
@@ -62,6 +62,49 @@ const char* GNU_gama_compiler =
 
 =============================================================================
 
+
+
+1.8.00 2005-12-28
+
+     #####################################################################
+     #                                                                   #
+     #  stable version 1.8  (branch gama-1-8-00 at cvs.sv.gnu.org)       #
+     #                                                                   #
+     #####################################################################
+
+
+
+    ------------------------------------------------------------------------
+
+    - Anton Horpynich <anton@vingeo.com> translated gama-local *.lang
+      files to Ukraininan
+
+    - Anton Horpynich revied Russian translation of *.lang files
+
+    - added first draft of template class SparseMatrixGraph (this
+      version only tests cennectivity of a given sparse matrix' graph)
+
+    - fixed matvec/mavecbase,h 
+
+      diff -r1.2 matvecbase.h
+      60c60
+      <   void set_zero() { set_all(0.0); }
+      ---
+      >   void set_zero() { set_all(Float()); }
+      108c108
+      <        return (x >= Float(0)) ? x : -x ;
+      ---
+      >        return (x >= Float()) ? x : -x ;
+      112c112
+      <        return b >= 0.0 ? Abs(a) : -Abs(a);
+      ---
+      >        return b >= Float() ? Abs(a) : -Abs(a);
+
+    - added missing test for coordinates and vectors for huge abs. terms
+      in LocalNetwork::test_abs_term(Index)
+
+
+
 1.7.14 2005-09-30
 
     - fixed bug reported by Zoltan Faludi
@@ -379,9 +422,9 @@ const char* GNU_gama_compiler =
 
     - a bug in the second GSO constructor
 
-        <  *  $Id: version.cpp,v 1.83 2005/09/30 11:52:02 cepek Exp $
+        <  *  $Id: version.cpp,v 1.92 2005/12/28 20:59:09 cepek Exp $
         ---
-        >  *  $Id: version.cpp,v 1.83 2005/09/30 11:52:02 cepek Exp $
+        >  *  $Id: version.cpp,v 1.92 2005/12/28 20:59:09 cepek Exp $
         80,83c80
         <   GSO(Mat<Float, Exc>& a, Index m, Index n)
         <     : pA(0), M(0), N(0), sc(true), tol_(0),
