@@ -2,7 +2,7 @@
     Geodesy and Mapping C++ Library (GNU GaMa / GaMaLib)
     Copyright (C) 2000  Petr Doubrava <petr@gepro.cz>
 
-    This file is part of the GNU GaMa / GaMaLib C++ Library.
+    This file is part of the GNU Gama C++ library.
     
     This library is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -20,7 +20,7 @@
 */
 
 /*
- *  $Id: encoding.cpp,v 1.3 2005/05/07 18:06:20 cepek Exp $
+ *  $Id: encoding.cpp,v 1.6 2005/08/22 16:46:11 cepek Exp $
  */
 
 #include <string.h>
@@ -363,15 +363,17 @@ char* utf8_ascii(char *buf){
   return buf; 
 }
 
-                   
-int UnknownEncodingHandler(void *userData, const char *name,XML_Encoding *info)
-{
- if (!strcmp(name,"cp-1250")) cp1250_unicode(info->map);
- else if (!strcmp(name,"windows-1250")) cp1250_unicode(info->map); /* this is probably correct */
- else if (!strcmp(name,"iso-8859-2")) iso_8859_2_unicode(info->map);
- else ascii(info->map);
- return 1;
-}
+
+// moved to file encoding_unknown_handler.cpp
+//                    
+// int UnknownEncodingHandler(void *userData, const char *name,XML_Encoding *info)
+// {
+//  if (!strcmp(name,"cp-1250")) cp1250_unicode(info->map);
+//  else if (!strcmp(name,"windows-1250")) cp1250_unicode(info->map); /* this is probably correct */
+//  else if (!strcmp(name,"iso-8859-2")) iso_8859_2_unicode(info->map);
+//  else ascii(info->map);
+//  return 1;
+// }
 
 #ifdef __cplusplus
 }   //  namespace GNU_gama
